@@ -18,6 +18,9 @@
 #  i386OPTIMIZE ="-march=prescott -mtune=pentium-m -ftree-vectorize" \
 #  OTHERARGs="";
 
+# -------------------------------
+# 20091206.0 sg Script tested and used to build 2009.4.0-RC3
+# -------------------------------
 
 BOOST_VER="1_40"
 
@@ -28,7 +31,7 @@ rm -rf "$REPOSITORYDIR/include/boost";
 cp -R "./boost" "$REPOSITORYDIR/include/";
 
 
-# compile bjab
+# compile bjam
 
 cd "./tools/jam/src";
 sh "build.sh";
@@ -63,8 +66,8 @@ do
   OPTIMIZE=$i386OPTIMIZE
   boostARCHITECTURE="x86"
   boostADDRESSMODEL="32"
-  export CC=$I386CC;
-  export CXX=$I386CXX;
+  export CC=$i386CC;
+  export CXX=$i386CXX;
  elif [ $ARCH = "ppc" -o $ARCH = "ppc750" -o $ARCH = "ppc7400" ]
  then
   MACSDKDIR=$ppcMACSDKDIR
@@ -139,56 +142,57 @@ then
  mv ./stage-$ARCH/lib/libboost_system.a ./stage-$ARCH/lib/libboost_system-$BOOST_VER.a
 done
 
-read pipo
+#read pipo
 
 # merge libboost_thread libboost_filesystem libboost_system
 
 for liba in "lib/libboost_thread-$BOOST_VER.a" "lib/libboost_filesystem-$BOOST_VER.a" "lib/libboost_thread-$BOOST_VER.dylib"  "lib/libboost_filesystem-$BOOST_VER.dylib"
 do
 
- if [ $NUMARCH -eq 1 ]
- then
-  mv "stage-$ARCH/$liba" "$REPOSITORYDIR/$liba";
-  if [[ $liba == *.a ]]
-  then 
-   ranlib "$REPOSITORYDIR/$liba";
-  fi
-  continue
+ if [ $NUMARCH -eq 1 ] ; then
+   if [ -f stage-$ARCHS/$liba ] ; then
+		 echo "Moving stage-$ARCHS/$liba to $liba"
+  	 mv "stage-$ARCHS/$liba" "$REPOSITORYDIR/$liba";
+	   #Power programming: if filename ends in "a" then ...
+	   [ ${liba##*.} = a ] && ranlib "$REPOSITORYDIR/$liba";
+  	 continue
+	 else
+		 echo "Program arch/$ARCHS/$liba not found. Aborting build";
+		 exit 1;
+	 fi
  fi
 
  LIPOARGs=""
  
  for ARCH in $ARCHS
  do
-  LIPOARGs="$LIPOARGs stage-$ARCH/$liba"
+  if [ -f stage-$ARCH/$liba ] ; then
+		echo "Adding stage-$ARCH/$liba to bundle"
+  	LIPOARGs="$LIPOARGs stage-$ARCH/$liba"
+	else
+		echo "File stage-$ARCH/$liba was not found. Aborting build";
+		exit 1;
+	fi
  done
 
  lipo $LIPOARGs -create -output "$REPOSITORYDIR/$liba";
- if [[ $liba == *.a ]]
- then 
-  ranlib "$REPOSITORYDIR/$liba";
- fi
+ #Power programming: if filename ends in "a" then ...
+ [ ${liba##*.} = a ] && ranlib "$REPOSITORYDIR/$liba";
 
 done
 
 
-if [ -f "$REPOSITORYDIR/lib/libboost_thread-$BOOST_VER.a" ]
-then
- ln -sfn libboost_thread-$BOOST_VER.a $REPOSITORYDIR/lib/libboost_thread.a;
+if [ -f "$REPOSITORYDIR/lib/libboost_thread-$BOOST_VER.a" ] ; then
+  ln -sfn libboost_thread-$BOOST_VER.a $REPOSITORYDIR/lib/libboost_thread.a;
 fi
-if [ -f "$REPOSITORYDIR/lib/libboost_thread-$BOOST_VER.dylib" ]
-then
+if [ -f "$REPOSITORYDIR/lib/libboost_thread-$BOOST_VER.dylib" ] ; then
  install_name_tool -id "$REPOSITORYDIR/lib/libboost_thread-$BOOST_VER.dylib" "$REPOSITORYDIR/lib/libboost_thread-$BOOST_VER.dylib";
  ln -sfn libboost_thread-$BOOST_VER.dylib $REPOSITORYDIR/lib/libboost_thread.dylib;
 fi
-
-if [ -f "$REPOSITORYDIR/lib/libboost_filesystem-$BOOST_VER.a" ]
-then
- ln -sfn libboost_filesystem-$BOOST_VER.a $REPOSITORYDIR/lib/libboost_fileystem.a;
+if [ -f "$REPOSITORYDIR/lib/libboost_filesystem-$BOOST_VER.a" ] ; then
+  ln -sfn libboost_filesystem-$BOOST_VER.a $REPOSITORYDIR/lib/libboost_fileystem.a;
 fi
-if [ -f "$REPOSITORYDIR/lib/libboost_filesystem-$BOOST_VER.dylib" ]
-then
+if [ -f "$REPOSITORYDIR/lib/libboost_filesystem-$BOOST_VER.dylib" ]; then
  install_name_tool -id "$REPOSITORYDIR/lib/libboost_filesystem-$BOOST_VER.dylib" "$REPOSITORYDIR/lib/libboost_filesystem-$BOOST_VER.dylib";
  ln -sfn libboost_filesystem-$BOOST_VER.dylib $REPOSITORYDIR/lib/libboost_filesystem.dylib;
 fi
-
