@@ -18,17 +18,16 @@
 #  ppc64ONLYARG="-mcpu=G5 -mtune=G5 -ftree-vectorize" \
 #  OTHERARGs="";
 
-
+# -------------------------------
+# 20091206.0 sg Script tested and used to build 2009.4.0-RC3
+# -------------------------------
 
 PNGVER="1.2.38"
 
-
 # init
 
 let NUMARCH="0"
-
-for i in $ARCHS
-do
+for i in $ARCHS ; do
   NUMARCH=$(($NUMARCH + 1))
 done
 
@@ -39,12 +38,63 @@ mkdir -p "$REPOSITORYDIR/include";
 
 # patch
 
-# makefile.darwin
+# pngconf.h
+if [ -f pngconf-bk.h ]
+then
+ mv -f pngconf-bk.h pngconf.h
+fi
+cp pngconf.h pngconf-bk.h
+patch < ../scripts/pngconf_h.patch
+
+
+# compile
+
+for ARCH in $ARCHS
+do
+
+ mkdir -p "$REPOSITORYDIR/arch/$ARCH/bin";
+ mkdir -p "$REPOSITORYDIR/arch/$ARCH/lib";
+ mkdir -p "$REPOSITORYDIR/arch/$ARCH/include";
+
+ ARCHARGs=""
+ MACSDKDIR=""
+
+ if [ $ARCH = "i386" -o $ARCH = "i686" ] ; then
+   TARGET=$i386TARGET
+   MACSDKDIR=$i386MACSDKDIR
+   ARCHARGs="$i386ONLYARG"
+   OSVERSION="$i386OSVERSION"
+   CC=$i386CC
+   CXX=$i386CXX
+ elif [ $ARCH = "ppc" -o $ARCH = "ppc750" -o $ARCH = "ppc7400" ] ; then
+   TARGET=$ppcTARGET
+   MACSDKDIR=$ppcMACSDKDIR
+   ARCHARGs="$ppcONLYARG"
+   OSVERSION="$ppcOSVERSION"
+   CC=$ppcCC
+   CXX=$ppcCXX
+ elif [ $ARCH = "ppc64" -o $ARCH = "ppc970" ] ; then
+   TARGET=$ppc64TARGET
+   MACSDKDIR=$ppc64MACSDKDIR
+   ARCHARGs="$ppc64ONLYARG"
+   OSVERSION="$ppc64OSVERSION"
+   CC=$ppc64CC
+   CXX=$ppc64CXX
+ elif [ $ARCH = "x86_64" ] ; then
+   TARGET=$x64TARGET
+   MACSDKDIR=$x64MACSDKDIR
+   ARCHARGs="$x64ONLYARG"
+   OSVERSION="$x64OSVERSION"
+   CC=$x64CC
+   CXX=$x64CXX
+ fi
+
+ # makefile.darwin
 #  includes hack for libpng bug #2009836
-if [ $CC != "" ]
+if [ -n $CC ]
 then 
  sed -e 's/-dynamiclib/-dynamiclib \$\(GCCLDFLAGS\)/g' \
-     -e "s/CC=cc/CC=$CC/" \
+     -e "s/CC=.*/CC=$CC/" \
      -e 's/compatibility_version \$(SONUM)/compatibility_version 1.2.0/g' \
      -e 's/current_version \$(SONUM)/current_version \$(PNGMIN)/g' \
      -e 's/compatibility_version %OLDSONUM%/compatibility_version 3.0.0/g' \
@@ -60,56 +110,16 @@ else
      scripts/makefile.darwin > makefile;
 fi
 
-# pngconf.h
-if [ -f pngconf-bk.h ]
-then
- mv -f pngconf-bk.h pngconf.h
-fi
-cp pngconf.h pngconf-bk.h
-patch < $(dirname $0)/pngconf_h.patch
-
-
-# compile
-
-for ARCH in $ARCHS
-do
-
- mkdir -p "$REPOSITORYDIR/arch/$ARCH/bin";
- mkdir -p "$REPOSITORYDIR/arch/$ARCH/lib";
- mkdir -p "$REPOSITORYDIR/arch/$ARCH/include";
-
- ARCHARGs=""
- MACSDKDIR=""
-
- if [ $ARCH = "i386" -o $ARCH = "i686" ]
- then
-  TARGET=$i386TARGET
-  MACSDKDIR=$i386MACSDKDIR
-  ARCHARGs="$i386ONLYARG"
- elif [ $ARCH = "ppc" -o $ARCH = "ppc750" -o $ARCH = "ppc7400" ]
- then
-  TARGET=$ppcTARGET
-  MACSDKDIR=$ppcMACSDKDIR
-  ARCHARGs="$ppcONLYARG"
- elif [ $ARCH = "ppc64" -o $ARCH = "ppc970" ]
- then
-  TARGET=$ppc64TARGET
-  MACSDKDIR=$ppc64MACSDKDIR
-  ARCHARGs="$ppc64ONLYARG"
- elif [ $ARCH = "x86_64" ]
- then
-  TARGET=$x64TARGET
-  MACSDKDIR=$x64MACSDKDIR
-  ARCHARGs="$x64ONLYARG"
- fi
-
  make clean;
  make $OTHERMAKEARGs install-static install-shared \
   prefix="$REPOSITORYDIR" \
   ZLIBLIB="$MACSDKDIR/usr/lib" \
   ZLIBINC="$MACSDKDIR/usr/include" \
+  CC="$CC" CXX="$CXX" \
   CFLAGS="-isysroot $MACSDKDIR -arch $ARCH $ARCHARGs $OTHERARGs -O2 -dead_strip" \
-  LDFLAGS="-L$REPOSITORYDIR/lib -L. -L$ZLIBLIB -lpng12 -lz" \
+  OBJCFLAGS="-arch $ARCH" \
+  OBJCXXFLAGS="-arch $ARCH" \
+  LDFLAGS="-L$REPOSITORYDIR/lib -L. -L$ZLIBLIB -lpng12 -lz -mmacosx-version-min=$OSVERSION" \
   NEXT_ROOT="$MACSDKDIR" \
   LIBPATH="$REPOSITORYDIR/arch/$ARCH/lib" \
   BINPATH="$REPOSITORYDIR/arch/$ARCH/bin" \
@@ -117,51 +127,52 @@ do
 
 done
 
-
 # merge libpng
 
 for liba in lib/libpng12.a lib/libpng12.12.$PNGVER.dylib lib/libpng.3.$PNGVER.dylib
 do
 
- if [ $NUMARCH -eq 1 ]
- then
-  mv "$REPOSITORYDIR/arch/$ARCHS/$liba" "$REPOSITORYDIR/$liba";
-  if [[ $liba == *.a ]]
-  then 
-   ranlib "$REPOSITORYDIR/$liba";
-  fi
-  continue
+ if [ $NUMARCH -eq 1 ] ; then
+   if [ -f $REPOSITORYDIR/arch/$ARCHS/$liba ] ; then
+		 echo "Moving arch/$ARCHS/$liba to $liba"
+  	 mv "$REPOSITORYDIR/arch/$ARCHS/$liba" "$REPOSITORYDIR/$liba";
+	   #Power programming: if filename ends in "a" then ...
+	   [ ${liba##*.} = a ] && ranlib "$REPOSITORYDIR/$liba";
+  	 continue
+	 else
+		 echo "Program arch/$ARCHS/$liba not found. Aborting build";
+		 exit 1;
+	 fi
  fi
 
  LIPOARGs=""
  
  for ARCH in $ARCHS
  do
-  LIPOARGs="$LIPOARGs $REPOSITORYDIR/arch/$ARCH/$liba"
+	if [ -f $REPOSITORYDIR/arch/$ARCH/$liba ] ; then
+		echo "Adding arch/$ARCH/$liba to bundle"
+		LIPOARGs="$LIPOARGs $REPOSITORYDIR/arch/$ARCH/$liba"
+	else
+		echo "File arch/$ARCH/$liba was not found. Aborting build";
+		exit 1;
+	fi
  done
 
  lipo $LIPOARGs -create -output "$REPOSITORYDIR/$liba";
- if [[ $liba == *.a ]]
- then 
-  ranlib "$REPOSITORYDIR/$liba";
- fi
+ #Power programming: if filename ends in "a" then ...
+ [ ${liba##*.} = a ] && ranlib "$REPOSITORYDIR/$liba";
 
 done
 
-
-if [ -f "$REPOSITORYDIR/lib/libpng12.a" ]
-then
- ln -sfn libpng12.a $REPOSITORYDIR/lib/libpng.a;
+if [ -f "$REPOSITORYDIR/lib/libpng12.a" ] ; then
+  ln -sfn libpng12.a $REPOSITORYDIR/lib/libpng.a;
 fi
-
-if [ -f "$REPOSITORYDIR/lib/libpng12.12.$PNGVER.dylib" ]
-then
+if [ -f "$REPOSITORYDIR/lib/libpng12.12.$PNGVER.dylib" ] ; then
  install_name_tool -id "$REPOSITORYDIR/lib/libpng12.1.dylib" "$REPOSITORYDIR/lib/libpng12.12.$PNGVER.dylib"
  ln -sfn libpng12.12.$PNGVER.dylib $REPOSITORYDIR/lib/libpng12.12.dylib;
  ln -sfn libpng12.12.dylib $REPOSITORYDIR/lib/libpng12.dylib;
 fi
-if [ -f "$REPOSITORYDIR/lib/libpng.3.$PNGVER.dylib" ]
-then
+if [ -f "$REPOSITORYDIR/lib/libpng.3.$PNGVER.dylib" ] ; then
  install_name_tool -id "$REPOSITORYDIR/lib/libpng.3.dylib" "$REPOSITORYDIR/lib/libpng.3.$PNGVER.dylib"
  ln -sfn libpng.3.$PNGVER.dylib $REPOSITORYDIR/lib/libpng.3.dylib;
  ln -sfn libpng.3.dylib $REPOSITORYDIR/lib/libpng.dylib;
