@@ -32,13 +32,12 @@
 #include "Celeste.h"
 #include <sys/stat.h> 
 #include "hugin_config.h" 
+#include <hugin_version.h>
 
 #ifdef __WIN32__
 #include <windows.h>
 #endif
 
-#define VERSION 1.2
-
 using namespace std;
 
 bool fileexists(string strFilename) {
@@ -125,8 +124,8 @@ mask_format,vector<double>& svm_responses){
 			// Hugin files
 			if (start == ("i")){
 									
-				found = line.find("\"");
-				imagename = line.substr(found + 1, line.length() - found - 2);
+				found = line.find("n\"");
+				imagename = line.substr(found + 2, line.find("\"",found + 2) - found - 2);
 				//cout << imagename << endl;
 				
 			// (Old?) Autopano Pro files
@@ -239,25 +238,32 @@ mask_format,vector<double>& svm_responses){
 
 				// First CP of next image
 				
-				// Control point x
-				unsigned int xcp = atoi( tokens[3].substr(1, tokens[3].length()-1).c_str() );
+				// Control point x,y
+				unsigned int xcp, ycp;
+				for ( int i = 0; i < tokens.size(); i++)
+				  {
+				    if (tokens[i][0] == 'x')
+				      xcp = atoi( tokens[i].substr(1, tokens[i].length()-1).c_str() );
+				    else if (tokens[i][0] == 'y')
+				      ycp = atoi( tokens[i].substr(1, tokens[i].length()-1).c_str() );
+				  }
+	
 				xcps.push_back(xcp);
-			
-				// Control point y
-				unsigned int ycp = atoi( tokens[4].substr(1, tokens[4].length()-1).c_str() );
 				ycps.push_back(ycp);
 
 				counter = 1;
 				
 			}else{
-	
-				// Control point x
-				unsigned int xcp = atoi( tokens[3].substr(1, tokens[3].length()-1).c_str() );
-				xcps.push_back(xcp);
-			
-				// Control point y
-				unsigned int ycp = atoi( tokens[4].substr(1, tokens[4].length()-1).c_str() );
+				unsigned int xcp, ycp;
+				for ( int i = 0; i < tokens.size(); i++)
+				  {
+				    if (tokens[i][0] == 'x')
+				      xcp = atoi( tokens[i].substr(1, tokens[i].length()-1).c_str() );
+				    else if (tokens[i][0] == 'y')
+				      ycp = atoi( tokens[i].substr(1, tokens[i].length()-1).c_str() );
+				  }
 				ycps.push_back(ycp);
+				xcps.push_back(xcp);
 			
 				counter++;
 			
@@ -353,7 +359,7 @@ pto_file_top,vector<string>& pto_file_cps,vector<string>& pto_file_end,vector<do
 	
 		cout << "CP ";
 		unsigned int len = 0;
-		for (unsigned int t = 1; t < 7; t++){
+		for (unsigned int t = 1; t < tokens.size(); t++){
 			len += tokens[t].length();
 			cout << tokens[t] << " ";
 		}
@@ -396,7 +402,7 @@ static void usage(){
 	// Print usage and exit
 	cout << endl << "Celeste: Removes cloud-like control points from Hugin project files and creates image masks" << endl;
 	cout << "using Support Vector Machines." << endl;
-	cout << endl << "Version " << VERSION << endl;
+	cout << endl << "Version " << DISPLAY_VERSION << endl;
 	cout << endl << "Usage: celeste_standalone [options] image1 image2 [..]" << endl << endl;
 	cout << "Options:" << endl << endl;
 	cout << "  -i <filename>   Input Hugin PTO file. Control points over SVM threshold will" << endl;
@@ -526,7 +532,7 @@ int main(int argc, const char* argv[]){
 	// Print some stuff out
 	cout << endl << "Celeste: Removes cloud-like control points from Hugin project files and creates image masks" << endl;
 	cout << "using Support Vector Machines." << endl;
-	cout << endl << "Version " << VERSION << endl << endl;
+	cout << endl << "Version " << DISPLAY_VERSION << endl << endl;
 	cout << "Arguments:" << endl;
 	cout << "Input Hugin file:\t" << pto_file << endl;
 	cout << "Output Hugin file:\t" << output_pto << endl;
@@ -583,6 +589,6 @@ int main(int argc, const char* argv[]){
 
 	}
 
-	return(1);
+	return(0);
 	
 }	
