@@ -3,7 +3,7 @@
 *
 *  @author Ippei UKAI <ippei_ukai@mac.com>
 *
-*  $Id: MyExternalCmdExecDialog.cpp 4211 2009-08-15 04:01:15Z gpatters1 $
+*  $Id: MyExternalCmdExecDialog.cpp 4600 2009-10-11 12:08:03Z stativ $
 *
 *  This is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public
@@ -506,6 +506,14 @@ void MyExecPanel::OnProcessTerminated(MyPipedProcess *process, int pid, int stat
 
 }
 
+MyExecPanel::~MyExecPanel() {
+#ifdef HUGIN_EXEC_LISTBOX
+    delete m_lbox;
+#else
+    delete m_textctrl;
+#endif
+}
+
 
 // ----------------------------------------------------------------------------
 // MyProcess
@@ -629,6 +637,10 @@ int MyExecDialog::ExecWithRedirect(wxString cmd)
     return ShowModal();
 }
 
+MyExecDialog::~MyExecDialog() {
+    delete m_execPanel;
+}
+
 int MyExecuteCommandOnDialog(wxString command, wxString args, wxWindow* parent,
                              wxString title)
 {
@@ -741,6 +753,10 @@ void MyExternalCmdExecDialog::OnIdle(wxIdleEvent& event)
 #endif
 }
 
+MyExternalCmdExecDialog::~MyExternalCmdExecDialog() {
+    delete m_tbox;
+}
+
 //----------
 
 bool HuginPipedProcess::HasInput()
