@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: AssistantPanel.cpp 4362 2009-09-10 16:16:26Z yuv $
+ *  $Id: AssistantPanel.cpp 4782 2009-12-11 17:40:38Z jlegg $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -55,6 +55,7 @@
 #include "hugin/PanoDruid.h"
 #include "base_wx/MyProgressDialog.h"
 #include "hugin/config_defaults.h"
+#include <algorithms/control_points/CleanCP.h>
 
 // Celeste header
 #include "Celeste.h"
@@ -341,12 +342,15 @@ void AssistantPanel::panoramaChanged(PT::Panorama &pano)
                 }
             }
         }
-        // need to resize the text widget somehow!
         m_alignText->SetLabel(alignMsg);
+        /** @todo Use width of avaliable space to wrap this message.
+         */
+        m_alignText->Wrap(600);
     } else {
         m_alignText->SetLabel(wxT(""));
     }
     // re-layout panel (adjusts m_alignText size)
+    m_panel->Layout();
     m_panel->FitInside();
 
     // TODO: update meaningful help text and dynamic links to relevant tabs
@@ -394,7 +398,7 @@ void AssistantPanel::OnAlign( wxCommandEvent & e )
 
     bool createCtrlP = m_pano->getNrOfCtrlPoints() == 0;
 
-    ProgressReporterDialog progress(5, _("Aligning images"), _("Finding corresponding points"),this);
+    ProgressReporterDialog progress(6, _("Aligning images"), _("Finding corresponding points"),this);
     wxString alignMsg;
     if (createCtrlP) {
         AutoCtrlPointCreator matcher;
@@ -406,7 +410,7 @@ void AssistantPanel::OnAlign( wxCommandEvent & e )
 
     // Run Celeste
     bool t = (wxConfigBase::Get()->Read(wxT("/Celeste/Auto"), HUGIN_CELESTE_AUTO) != 0); 
-    if (t && m_pano->getNrOfCtrlPoints())
+    if (t && createCtrlP && m_pano->getNrOfCtrlPoints())
     {
 
         DEBUG_TRACE("Running Celeste");
@@ -490,32 +494,72 @@ void AssistantPanel::OnAlign( wxCommandEvent & e )
                 // Get responses
                 get_gabor_response(imagefile, mask, strModelFileName, threshold, mask_format, svm_responses_ap);
 
+                UIntSet cpToRemove;
                 // Print SVM results
                 for (unsigned int c = 0; c < svm_responses_ap.size(); c++){
-
-                    unsigned int pNr = global_cp_nr[c] - removed;	
-
                     if (svm_responses_ap[c] >= threshold){
-
-                        DEBUG_DEBUG("about to delete point " << pNr);
-                        GlobalCmdHist::getInstance().addCommand(
-                            new PT::RemoveCtrlPointCmd(*m_pano,pNr)
-                            );
-                        removed++;					
+                        DEBUG_DEBUG("about to delete point " << global_cp_nr[c]);
+                        cpToRemove.insert(global_cp_nr[c]);
+                        removed++;
                         cout << "CP: " << c << "\tSVM Score: " << svm_responses_ap[c] << "\tremoved." << endl;
                     }
                 }
                 if (removed) cout << endl;
+                if(cpToRemove.size()>0)
+                    GlobalCmdHist::getInstance().addCommand(
+                        new PT::RemoveCtrlPointsCmd(*m_pano,cpToRemove)
+                        );
 
             }
         }else{	
             wxMessageBox(_("Celeste model file not found, Hugin needs to be properly installed." ), _("Fatal Error"));
         }	
 
-        MainFrame::Get()->SetStatusText(_(""),0);
+        MainFrame::Get()->SetStatusText(wxT(""),0);
     }
     DEBUG_TRACE("Finished running Celeste");
 
+    // run CPClean
+    progress.increaseProgress(1.0, std::wstring(wxString(_("Checking for outlying control points")).wc_str(wxConvLocal)));
+    t = (wxConfigBase::Get()->Read(wxT("/Assistant/AutoCPClean"), HUGIN_ASS_AUTO_CPCLEAN) != 0); 
+    if (t && createCtrlP && (m_pano->getNrOfCtrlPoints()>2))
+    {
+        deregisterPTWXDlgFcn();
+        UIntSet CPremove=getCPoutsideLimit_pair(*m_pano,2.0);
+        if(CPremove.size()>0)
+        {
+            GlobalCmdHist::getInstance().addCommand(
+                            new PT::RemoveCtrlPointsCmd(*m_pano,CPremove)
+                            );
+        };
+        CPremove.clear();
+        //check for unconnected images
+        CPGraph graph;
+        createCPGraph(*m_pano, graph);
+        CPComponents comps;
+        int n = findCPComponents(graph, comps);
+
+        if (n > 1) {
+            registerPTWXDlgFcn(MainFrame::Get());
+            // switch to images panel.
+            unsigned i1 = *(comps[0].rbegin());
+            unsigned i2 = *(comps[1].begin());
+            MainFrame::Get()->ShowCtrlPointEditor( i1, i2);
+            // display message box with 
+            wxMessageBox(wxString::Format(_("Warning %d unconnected image groups found:"), n) + Components2Str(comps) + wxT("\n")
+                + _("Please create control points between unconnected images using the Control Points tab.\n\nAfter adding the points, press the \"Align\" button again"),_("Error"), wxOK , this);
+            return;
+        }
+        CPremove=getCPoutsideLimit(*m_pano,2.0);
+        registerPTWXDlgFcn(MainFrame::Get());
+        if(CPremove.size()>0)
+        {
+            GlobalCmdHist::getInstance().addCommand(
+                            new PT::RemoveCtrlPointsCmd(*m_pano,CPremove)
+                            );
+        };
+    };
+
     progress.increaseProgress(1.0, std::wstring(wxString(_("Determining placement of the images")).wc_str(wxConvLocal)));
 
     // find components..
@@ -713,7 +757,7 @@ void AssistantPanel::OnAlign( wxCommandEvent & e )
 
     // show preview frame
     wxCommandEvent dummy;
-    long preview=wxConfigBase::Get()->Read(wxT("/Assistant/PreviewWindow"),1l);
+    long preview=wxConfigBase::Get()->Read(wxT("/Assistant/PreviewWindow"),HUGIN_ASS_PREVIEW);
     switch(preview)
     {
         case 1:   
