@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: CPEditorPanel.cpp 3972 2009-06-28 22:30:16Z gpatters1 $
+ *  $Id: CPEditorPanel.cpp 4789 2009-12-14 06:53:35Z harryvanderwolf $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -26,7 +26,13 @@
 
 #include <config.h>
 
+// often necessary before panoinc.h
+#ifdef __APPLE__
 #include "panoinc_WX.h"
+#endif
+// standard hugin include
+#include "panoinc.h"
+// both includes above need to come before other wx includes on OSX
 
 // hugin's
 #include "hugin/huginApp.h"
@@ -45,8 +51,6 @@
 #include <float.h>
 #include <vector>
 
-// standard hugin include
-#include "panoinc.h"
 
 // more vigra include if needed
 #include "vigra/cornerdetection.hxx"
@@ -282,7 +286,7 @@ bool CPEditorPanel::Create(wxWindow* parent, wxWindowID id,
     wxConfigBase *config = wxConfigBase::Get();
 
     m_autoAddCB->SetValue(config->Read(wxT("/CPEditorPanel/autoAdd"),0l) != 0 );
-    m_fineTuneCB->SetValue(config->Read(wxT("/CPEditorPanel/fineTune"),1l) != 0 );
+    m_fineTuneCB->SetValue(config->Read(wxT("/CPEditorPanel/autoFineTune"),1l) != 0 );
     m_estimateCB->SetValue(config->Read(wxT("/CPEditorPanel/autoEstimate"),1l) != 0 );
 
     // disable controls by default
@@ -2141,10 +2145,6 @@ void CPEditorPanel::OnCelesteButton(wxCommandEvent & e)
 
         ProgressReporterDialog progress(3, _("Running Celeste"), _("Running Celeste"),this);
 
-        // set numeric locale to C, for correct number output
-        char * old_locale = setlocale(LC_NUMERIC,NULL);
-        setlocale(LC_NUMERIC,"C");	
-
         MainFrame::Get()->SetStatusText(_("searching for cloud-like control points..."),0);
 
         // Create the storage matrix
@@ -2177,13 +2177,13 @@ void CPEditorPanel::OnCelesteButton(wxCommandEvent & e)
 
         // determine file name of SVM model file
         // get XRC path from application
-        wxString wxstrModelFileName = huginApp::Get()->GetXRCPath() + wxT("data/") + wxT(HUGIN_CELESTE_MODEL);
+        wxString wxstrModelFileName = huginApp::Get()->GetDataPath() + wxT(HUGIN_CELESTE_MODEL);
         // convert wxString to string
         string strModelFileName(wxstrModelFileName.mb_str(wxConvUTF8));
 				
         // SVM model file
         if (! wxFile::Exists(wxstrModelFileName) ) {
-            wxMessageBox(_("Celeste model file not found, Hugin needs to be properly installed." ), _("Fatal Error"));
+            wxMessageBox(_("Celeste model expected in ") + wxstrModelFileName +_(" not found, Hugin needs to be properly installed." ), _("Fatal Error"));
             return ;
         }
 
@@ -2206,15 +2206,14 @@ void CPEditorPanel::OnCelesteButton(wxCommandEvent & e)
 
         // Print SVM results
         unsigned int removed = 0;
+        UIntSet cpToRemove;
         for (unsigned int c = 0; c < svm_responses_cp.size(); c++){
 
             if (svm_responses_cp[c] >= threshold){
 
-                unsigned int pNr = localPNr2GlobalPNr((c - removed));
+                unsigned int pNr = localPNr2GlobalPNr(c);
+                cpToRemove.insert(pNr);
                 DEBUG_DEBUG("about to delete point " << pNr);
-                GlobalCmdHist::getInstance().addCommand(
-                    new PT::RemoveCtrlPointCmd(*m_pano,pNr)
-                    );
                 removed++;
                 cout << "CP: " << c << "\tSVM Score: " << svm_responses_cp[c] << "\tremoved." << endl;
             }
@@ -2223,6 +2222,10 @@ void CPEditorPanel::OnCelesteButton(wxCommandEvent & e)
                 cout << endl;
             }
         }
+        if(cpToRemove.size()>0)
+            GlobalCmdHist::getInstance().addCommand(
+                new PT::RemoveCtrlPointsCmd(*m_pano,cpToRemove)
+                );
 
         progress.increaseProgress(1.0, std::wstring(wxString(_("Running Celeste")).wc_str(wxConvLocal)));
 
@@ -2230,10 +2233,7 @@ void CPEditorPanel::OnCelesteButton(wxCommandEvent & e)
 
         DEBUG_TRACE("Finished running Celeste");
 
-        MainFrame::Get()->SetStatusText(_(""),0);
-
-        // reset locale
-        setlocale(LC_NUMERIC,old_locale);
+        MainFrame::Get()->SetStatusText(wxT(""),0);
     }
 }
 
