@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: CPImageCtrl.cpp 3168 2008-07-05 21:16:04Z gpatters1 $
+ *  $Id: CPImageCtrl.cpp 4738 2009-12-01 16:57:20Z harryvanderwolf $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -1301,9 +1301,7 @@ void CPImageCtrl::OnKey(wxKeyEvent & e)
             case WXK_LEFT:
             case WXK_UP:
             case WXK_DOWN:
-#ifdef __WXMSW__
             case WXK_DELETE:
-#endif
                 forward = true;
                 break;
             default:
@@ -1387,7 +1385,7 @@ void CPImageCtrl::OnMouseEnter(wxMouseEvent & e)
 FDiff2D CPImageCtrl::getNewPoint()
 {
     // only possible if a new point is actually selected
-    DEBUG_ASSERT(editState == NEW_POINT_SELECTED);
+    // DEBUG_ASSERT(editState == NEW_POINT_SELECTED);
     return newPoint;
 }
 
