@@ -7,7 +7,7 @@
  *  @author Kai-Uwe Behrmann <web@tiscali.de> and
  *          Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: ImagesPanel.cpp 4235 2009-08-17 03:19:23Z gpatters1 $
+ *  $Id: ImagesPanel.cpp 4853 2010-01-06 06:20:44Z tmodes $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -48,6 +48,9 @@
 #include "hugin/AutoCtrlPointCreator.h"
 #include "hugin/config_defaults.h"
 #include "base_wx/MyProgressDialog.h"
+#include "base_wx/PTWXDlg.h"
+#include <algorithms/control_points/CleanCP.h>
+#include <PT/PTOptimise.h>
 
 // Celeste header
 #include "Celeste.h"
@@ -77,6 +80,7 @@ BEGIN_EVENT_TABLE(ImagesPanel, wxPanel)
     EVT_BUTTON     ( XRCID("images_opt_anchor_button"), ImagesPanel::OnOptAnchorChanged)
     EVT_BUTTON     ( XRCID("images_color_anchor_button"), ImagesPanel::OnColorAnchorChanged)
     EVT_BUTTON     ( XRCID("images_feature_matching"), ImagesPanel::SIFTMatching)
+    EVT_BUTTON     ( XRCID("images_cp_clean"), ImagesPanel::OnCleanCP)
     EVT_BUTTON     ( XRCID("images_remove_cp"), ImagesPanel::OnRemoveCtrlPoints)
     EVT_BUTTON     ( XRCID("images_reset_pos"), ImagesPanel::OnResetImagePositions)
     EVT_BUTTON     ( XRCID("action_remove_images"),  ImagesPanel::OnRemoveImages)
@@ -121,6 +125,8 @@ bool ImagesPanel::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos, co
     DEBUG_ASSERT(m_colorAnchorButton);
     m_matchingButton = XRCCTRL(*this, "images_feature_matching", wxButton);
     DEBUG_ASSERT(m_matchingButton);
+    m_cleaningButton = XRCCTRL(*this, "images_cp_clean", wxButton);
+    DEBUG_ASSERT(m_cleaningButton);
     m_removeCPButton = XRCCTRL(*this, "images_remove_cp", wxButton);
     DEBUG_ASSERT(m_removeCPButton);
     m_moveUpButton = XRCCTRL(*this, "images_move_image_up", wxButton);
@@ -235,6 +241,15 @@ void ImagesPanel::panoramaImagesChanged(PT::Panorama &pano, const PT::UIntSet &
         m_removeCPButton->Enable();
         m_matchingButton->Enable();
     }
+    if (pano.getNrOfImages()>1)
+    {
+        if(pano.getNrOfCtrlPoints()>2)
+            m_cleaningButton->Enable();
+        else
+            m_cleaningButton->Disable();
+    }
+    else
+        m_cleaningButton->Disable();
 
     if (selected.size() == 1 &&
         *(selected.begin()) < pano.getNrOfImages() &&
@@ -285,13 +300,60 @@ void ImagesPanel::SIFTMatching(wxCommandEvent & e)
     CPVector cps = matcher.automatch(cpdetector_config.settings[m_CPDetectorChoice->GetSelection()],
         *pano, selImg, nFeatures,this);
     wxString msg;
-    wxMessageBox(wxString::Format(_("Added %d control points"), cps.size()), _("Autopano result"),wxOK|wxICON_INFORMATION,this);
+    wxMessageBox(wxString::Format(_("Added %d control points"), cps.size()), _("Control point detector result"),wxOK|wxICON_INFORMATION,this);
     GlobalCmdHist::getInstance().addCommand(
             new PT::AddCtrlPointsCmd(*pano, cps)
                                            );
 
 };
 
+void ImagesPanel::OnCleanCP(wxCommandEvent & e)
+{
+    if (pano->getNrOfImages()<2)
+        return;
+
+    if (pano->getNrOfCtrlPoints()<2)
+        return;
+
+    deregisterPTWXDlgFcn();
+    // work around a flaw in wxProgresDialog that results in incorrect layout
+    // by pre-allocting sufficient horizontal space
+    ProgressReporterDialog progress(2, _("Cleaning Control points"), _("Checking pairwise")+wxString((wxChar)' ',10),this, wxPD_AUTO_HIDE | wxPD_APP_MODAL | wxPD_ELAPSED_TIME);
+    UIntSet CPremove=getCPoutsideLimit_pair(*pano,2.0);
+    
+    unsigned int NrRemoved=CPremove.size();
+    if(NrRemoved>0)
+    {
+        GlobalCmdHist::getInstance().addCommand(
+                        new PT::RemoveCtrlPointsCmd(*pano,CPremove)
+                        );
+        
+    };
+    CPremove.clear();
+    
+    //check for unconnected images
+    CPGraph graph;
+    createCPGraph(*pano, graph);
+    CPComponents comps;
+    int n=findCPComponents(graph, comps);
+    progress.increaseProgress(1, std::wstring(wxString(_("Checking whole project")).wc_str(wxConvLocal)));
+    if (n <= 1)
+    {
+        CPremove=getCPoutsideLimit(*pano,2.0);
+    }
+    progress.increaseProgress(1, std::wstring(wxString(_("Finished cleaning")).wc_str(wxConvLocal)));
+    registerPTWXDlgFcn(MainFrame::Get());
+    if(CPremove.size()>0)
+    {
+        GlobalCmdHist::getInstance().addCommand(
+                        new PT::RemoveCtrlPointsCmd(*pano,CPremove)
+                        );
+        NrRemoved+=CPremove.size();
+    };
+    wxMessageBox(wxString::Format(_("Removed %d control points"), NrRemoved), _("Cleaning"),wxOK|wxICON_INFORMATION,this);
+};
+
+
 // Yaw by text -> double
 void ImagesPanel::OnYawTextChanged ( wxCommandEvent & e )
 {
@@ -537,7 +599,7 @@ void ImagesPanel::ShowExifInfo(unsigned int imgNr)
         else
             s=wxString::Format(wxT("%1.2f s"),img.getExifExposureTime());
     else {
-        if (img.getExifExposureTime() > 0) {
+        if (img.getExifExposureTime() > 1e-9) {
             s=wxString::Format(wxT("1/%0.0f s"),1.0/img.getExifExposureTime());
         } else {
             //Sanity
@@ -936,19 +998,13 @@ void ImagesPanel::OnCelesteButton(wxCommandEvent & e)
 
             MainFrame::Get()->SetStatusText(_("classifying control points..."),0);
 
+            UIntSet cpToRemove;
             // Print SVM results
             for (unsigned int c = 0; c < svm_responses_im.size(); c++){
-
-                unsigned int pNr = global_cp_nr[c] - removed;	
-
                 if (svm_responses_im[c] >= threshold){
-
-                    DEBUG_DEBUG("about to delete point " << pNr);
-                    GlobalCmdHist::getInstance().addCommand(
-                        new PT::RemoveCtrlPointCmd(*pano,pNr)
-                        );
-                    removed++;	
-                    total_removed++;					
+                    cpToRemove.insert(global_cp_nr[c]);
+                    removed++;
+                    total_removed++;
                     cout << "CP: " << c << "\tSVM Score: " << svm_responses_im[c] << "\tremoved." << endl;
                 }
             }
@@ -956,8 +1012,13 @@ void ImagesPanel::OnCelesteButton(wxCommandEvent & e)
             {
                 cout << endl;
             }
+            if(cpToRemove.size()>0)
+                GlobalCmdHist::getInstance().addCommand(
+                    new PT::RemoveCtrlPointsCmd(*pano,cpToRemove)
+                    );
+
         }
-        MainFrame::Get()->SetStatusText(_(""),0);
+        MainFrame::Get()->SetStatusText(wxT(""),0);
 
     }
 
