@@ -3,7 +3,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: MainFrame.h 4090 2009-07-23 05:22:55Z tmodes $
+ *  $Id: MainFrame.h 4715 2009-11-12 06:21:24Z tmodes $
  *
  *  This is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -31,6 +31,8 @@
 #include "common/utils.h"
 #include "PT/Panorama.h"
 
+#include "wx/docview.h"
+
 #include "hugin/OptimizePanel.h"
 #include "hugin/PreferencesDialog.h"
 
@@ -180,13 +182,16 @@ private:
     void OnLoadProject(wxCommandEvent & e);
     void OnNewProject(wxCommandEvent & e);
     void OnAddTimeImages(wxCommandEvent & e);
-    void OnTextEdit(wxCommandEvent & e);
     void OnFineTuneAll(wxCommandEvent & e);
     void OnApplyTemplate(wxCommandEvent & e);
 	void OnSendToBatch(wxCommandEvent & e);
 	void OnOpenPTBatcher(wxCommandEvent & e);
 //    void OnToggleOptimizeFrame(wxCommandEvent & e);
     void OnShowCPFrame(wxCommandEvent & e);
+    /** event handler for recently used files */
+    void OnMRUFiles(wxCommandEvent &e);
+    /** event handler for full screen */
+    void OnFullScreen(wxCommandEvent &e);
     void UpdatePanels(wxCommandEvent & e);
     void OnSize(wxSizeEvent &e);
     void enableTools(bool option);
@@ -197,6 +202,7 @@ private:
     // update progress display
     bool displayProgress();
 
+    wxFileHistory m_mruFiles;
     wxNotebook * m_notebook;
     // tab panels
     AssistantPanel* assistant_panel;
@@ -231,9 +237,6 @@ private:
     // self
     static MainFrame* m_this;
 
-    // the help browser
-    wxHtmlHelpController * m_help;
-
     // progress reporter
     double m_progressMax;
     double m_progress;
