@@ -7,7 +7,7 @@
  *  @author Kai-Uwe Behrmann <web@tiscali.de> and
  *          Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: PanoPanel.cpp 4389 2009-09-12 23:20:32Z yuv $
+ *  $Id: PanoPanel.cpp 5034 2010-02-28 21:44:14Z brunopostle $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -42,7 +42,6 @@ extern "C" {
 #include <pano13/queryfeature.h>
 }
 
-#include "hugin/RunStitcherFrame.h"
 #include "hugin/CommandHistory.h"
 //#include "hugin/ImageCache.h"
 //#include "hugin/CPEditorPanel.h"
@@ -54,10 +53,9 @@ extern "C" {
 #include "hugin/PanoPanel.h"
 #include "hugin/MainFrame.h"
 #include "hugin/huginApp.h"
+#include "hugin/HDRMergeOptionDialog.h"
 #include "hugin/TextKillFocusHandler.h"
 #include "base_wx/MyProgressDialog.h"
-#include "hugin/PTStitcherPanel.h"
-#include "hugin/NonaStitcherPanel.h"
 #include "hugin/config_defaults.h"
 #include "base_wx/platform.h"
 #include "base_wx/huginConfig.h"
@@ -80,6 +78,7 @@ BEGIN_EVENT_TABLE(PanoPanel, wxPanel)
     EVT_TEXT_ENTER ( XRCID("pano_val_roi_left"),PanoPanel::ROIChanged )
     EVT_TEXT_ENTER ( XRCID("pano_val_roi_right"),PanoPanel::ROIChanged )
     EVT_BUTTON ( XRCID("pano_button_opt_width"), PanoPanel::DoCalcOptimalWidth)
+    EVT_BUTTON ( XRCID("pano_button_opt_roi"), PanoPanel::DoCalcOptimalROI)
     EVT_BUTTON ( XRCID("pano_button_stitch"),PanoPanel::OnDoStitch )
 	EVT_BUTTON ( XRCID("pano_button_batch"),PanoPanel::OnSendToBatch )
 
@@ -206,6 +205,9 @@ bool PanoPanel::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos, cons
     m_ROIBottomTxt = XRCCTRL(*this, "pano_val_roi_bottom", wxTextCtrl);
     DEBUG_ASSERT(m_ROIBottomTxt);
     m_ROIBottomTxt->PushEventHandler(new TextKillFocusHandler(this));
+    
+    m_CalcOptROIButton = XRCCTRL(*this, "pano_button_opt_roi" ,wxButton);
+    DEBUG_ASSERT(m_CalcOptROIButton);    
 
     m_RemapperChoice = XRCCTRL(*this, "pano_choice_remapper", wxChoice);
     DEBUG_ASSERT(m_RemapperChoice);
@@ -378,6 +380,7 @@ void PanoPanel::UpdateDisplay(const PanoramaOptions & opt, const bool hasStacks)
     m_VFOVText->Enable(m_keepViewOnResize);
     m_CalcOptWidthButton->Enable(m_keepViewOnResize && hasImages);
     m_CalcHFOVButton->Enable(m_keepViewOnResize && hasImages);
+    m_CalcOptROIButton->Enable(m_keepViewOnResize && hasImages);
 
     m_WidthTxt->SetValue(wxString::Format(wxT("%d"), opt.getWidth()));
     m_HeightTxt->SetValue(wxString::Format(wxT("%d"), opt.getHeight()));
@@ -693,6 +696,20 @@ void PanoPanel::ROIChanged ( wxCommandEvent & e )
         wxLogError(_("bottom needs to be an integer bigger than 0"));
         return;
     }
+    // make sure that left is really to the left of right
+    if(left>=right) {
+        wxLogError(_("left boundary must be smaller than right"));
+		// TODO: would be nice if the previous value would be restored
+        return;
+    }
+    // make sure that top is really higher than bottom
+    if(top>=bottom) {
+        wxLogError(_("top boundary must be smaller than bottom"));
+		// TODO: would be nice if the previous value would be restored
+        return;
+    }
+
+
     opt.setROI(vigra::Rect2D(left, top, right, bottom));
     GlobalCmdHist::getInstance().addCommand(
             new PT::SetPanoOptionsCmd( *pano, opt )
@@ -709,6 +726,7 @@ void PanoPanel::EnableControls(bool enable)
     m_BlenderChoice->Enable(enable);
 //    m_CalcHFOVButton->Enable(enable);
 //    m_CalcOptWidthButton->Enable(enable);
+//    m_CalcOptROIButton->Enable(enable);
 }
 
 void PanoPanel::RemapperChanged(wxCommandEvent & e)
@@ -796,6 +814,10 @@ void PanoPanel::OnBlenderOptions(wxCommandEvent & e)
             if (enblend_opts_text->GetValue().length() > 0) {
                 opt.enblendOptions = enblend_opts_text->GetValue().mb_str(wxConvLocal);
             }
+            else
+            {
+                opt.enblendOptions = wxConfigBase::Get()->Read(wxT("Enblend/Args"),wxT(HUGIN_ENBLEND_ARGS)).mb_str(wxConvLocal);
+            };
             GlobalCmdHist::getInstance().addCommand(
                 new PT::SetPanoOptionsCmd( *pano, opt )
                 );
@@ -824,6 +846,10 @@ void PanoPanel::OnFusionOptions(wxCommandEvent & e)
         if (enfuse_opts_text->GetValue().length() > 0) {
             opt.enfuseOptions = enfuse_opts_text->GetValue().mb_str(wxConvLocal);
         }
+        else
+        {
+            opt.enfuseOptions = wxConfigBase::Get()->Read(wxT("Enfuse/Args"),wxT(HUGIN_ENFUSE_ARGS)).mb_str(wxConvLocal);
+        };
         GlobalCmdHist::getInstance().addCommand(
             new PT::SetPanoOptionsCmd( *pano, opt )
             );
@@ -839,7 +865,20 @@ void PanoPanel::HDRMergeChanged(wxCommandEvent & e)
 
 void PanoPanel::OnHDRMergeOptions(wxCommandEvent & e)
 {
-    wxLogError(_("Not yet implemented"));
+    PanoramaOptions opt = pano->getOptions();
+    if (opt.hdrMergeMode == PanoramaOptions::HDRMERGE_AVERAGE) {
+        HDRMergeOptionsDialog dlg(this);
+        dlg.SetCommandLineArgument(wxString(opt.hdrmergeOptions.c_str(), wxConvLocal));
+        if (dlg.ShowModal() == wxOK) 
+        {
+            opt.hdrmergeOptions=dlg.GetCommandLineArgument().mb_str(wxConvLocal);
+            GlobalCmdHist::getInstance().addCommand(
+                new PT::SetPanoOptionsCmd( *pano, opt )
+                );
+        }
+    } else {
+        wxLogError(_(" Options for this HDRMerge program not yet implemented"));
+    }
 }
 
 
@@ -882,6 +921,42 @@ void PanoPanel::DoCalcOptimalWidth(wxCommandEvent & e)
 }
 
 
+void PanoPanel::DoCalcOptimalROI(wxCommandEvent & e)
+{
+    DEBUG_INFO("Dirty ROI Calc\n");
+    if (pano->getActiveImages().size() == 0) return;
+
+    ProgressReporterDialog progress(2, _("Autocrop"), _("Calculating optimal crop"),this, wxPD_AUTO_HIDE | wxPD_APP_MODAL | wxPD_ELAPSED_TIME);
+    progress.increaseProgress(1);
+    progress.Pulse();
+
+    //unsigned int left,top,right,bottom;
+    vigra::Rect2D newROI;
+    vigra::Size2D newSize;
+    
+    pano->calcOptimalROI(newROI,newSize);
+    
+    
+    PanoramaOptions opt = pano->getOptions();
+    
+    DEBUG_INFO ( "ROI: left: " << opt.getROI().left() << "  top: " << opt.getROI().top() << " right: " << opt.getROI().right() << "  bottom: " << opt.getROI().bottom()  << "  before update");
+    
+    //set the ROI - fail if the right/bottom is zero, meaning all zero
+    if(newROI.right() != 0 && newROI.bottom() != 0)
+    {
+        //opt.setWidth(newSize.x);
+        //opt.setHeight(newSize.y);
+        opt.setROI(newROI);
+
+        GlobalCmdHist::getInstance().addCommand(
+            new PT::SetPanoOptionsCmd( *pano, opt )
+            );
+    }
+    PanoramaOptions opt2 = pano->getOptions();
+    DEBUG_INFO ( "ROI: left: " << opt2.getROI().left() << "  top: " << opt2.getROI().top() << " right: " << opt2.getROI().right() << "  bottom: " << opt2.getROI().bottom()  << "  after update");
+    
+}
+
 void PanoPanel::DoStitch()
 {
     if (pano->getNrOfImages() == 0) {
