@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: PreferencesDialog.cpp 4358 2009-09-10 05:06:53Z yuv $
+ *  $Id: PreferencesDialog.cpp 5018 2010-02-23 22:42:08Z brunopostle $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -172,6 +172,9 @@ PreferencesDialog::PreferencesDialog(wxWindow *parent)
     lp = new long;
     *lp = wxLANGUAGE_UKRAINIAN;
     lang_choice->Append(_("Ukrainian"), lp);
+    lp = new long;
+    *lp = wxLANGUAGE_FINNISH;
+    lang_choice->Append(_("Finnish"), lp);
     lang_choice->SetSelection(0);
 
     // load autopano settings
@@ -376,14 +379,6 @@ void PreferencesDialog::EnableRotationCtrls(bool enable)
     XRCCTRL(*this, "prefs_ft_rot_panel", wxPanel)->Enable(enable);
 }
 
-#ifdef HAVE_PANO12_QUERYFEATURE_H
-typedef int (*PROC_QF)			(int ,char** ,Tp12FeatureType* );
-typedef int (*PROC_QFNUM)		(void);
-typedef int (*PROC_QFINT)		(const char *, int *);
-typedef int (*PROC_QFDOUBLE)	(const char *, double *);
-typedef int (*PROC_QFSTRING)	(const char *, char *, const int);
-#endif
-
 bool PreferencesDialog::GetPanoVersion()
 {
   return false;
@@ -461,7 +456,11 @@ void PreferencesDialog::UpdateDisplayData(int panel)
                    wxT(HUGIN_STITCHER_EDITOR)));
         MY_STR_VAL("prefs_ass_editor_args", cfg->Read(wxT("/Stitcher/EditorArgs"),
                    wxT(HUGIN_STITCHER_EDITOR_ARGS)));
-        MY_CHOICE_VAL("prefs_ass_preview", cfg->Read(wxT("/Assistant/PreviewWindow"), 1l));
+        MY_CHOICE_VAL("prefs_ass_preview", cfg->Read(wxT("/Assistant/PreviewWindow"), HUGIN_ASS_PREVIEW));
+        t = cfg->Read(wxT("/Celeste/Auto"), HUGIN_CELESTE_AUTO) == 1;
+        MY_BOOL_VAL("prefs_celeste_auto", t);
+        t = cfg->Read(wxT("/Assistant/AutoCPClean"), HUGIN_ASS_AUTO_CPCLEAN) == 1;
+        MY_BOOL_VAL("prefs_auto_cpclean", t);
     }
        // Fine tune settings
 
@@ -548,9 +547,6 @@ void PreferencesDialog::UpdateDisplayData(int panel)
     if (panel==0 || panel == 6) {
         // Celeste settings
 
-        t = cfg->Read(wxT("/Celeste/Auto"), HUGIN_CELESTE_AUTO) == 1;
-        MY_BOOL_VAL("prefs_celeste_auto", t);
-	
         d=HUGIN_CELESTE_THRESHOLD;
         cfg->Read(wxT("/Celeste/Threshold"), &d, HUGIN_CELESTE_THRESHOLD);
         tstr = utils::doubleTowxString(d);
@@ -617,7 +613,9 @@ void PreferencesDialog::OnRestoreDefaults(wxCommandEvent & e)
             cfg->Write(wxT("/Stitcher/RunEditor"), HUGIN_STITCHER_RUN_EDITOR);
             cfg->Write(wxT("/Stitcher/Editor"), wxT(HUGIN_STITCHER_EDITOR));
             cfg->Write(wxT("/Stitcher/EditorArgs"), wxT(HUGIN_STITCHER_EDITOR_ARGS));
-            cfg->Write(wxT("/Assistant/PreviewWindow"), 1l);
+            cfg->Write(wxT("/Assistant/PreviewWindow"), HUGIN_ASS_PREVIEW);
+            cfg->Write(wxT("/Celeste/Auto"), HUGIN_CELESTE_AUTO);
+            cfg->Write(wxT("/Assistant/AutoCPClean"), HUGIN_ASS_AUTO_CPCLEAN);
         }
         if (noteb->GetSelection() == 2) {
             // hdr
@@ -655,7 +653,6 @@ void PreferencesDialog::OnRestoreDefaults(wxCommandEvent & e)
 	
         if (noteb->GetSelection() == 5) {
             /// Celeste
-            cfg->Write(wxT("/Celeste/Auto"), HUGIN_CELESTE_AUTO);
             cfg->Write(wxT("/Celeste/Threshold"), HUGIN_CELESTE_THRESHOLD);
             cfg->Write(wxT("/Celeste/Filter"), HUGIN_CELESTE_FILTER);
         }	
@@ -687,6 +684,8 @@ void PreferencesDialog::UpdateConfigData()
     cfg->Write(wxT("/Assistant/nControlPoints"), MY_G_SPIN_VAL("prefs_ass_nControlPoints"));
     cfg->Write(wxT("/Assistant/panoDownsizeFactor"), MY_G_SPIN_VAL("prefs_ass_panoDownsizeFactor") / 100.0);
     cfg->Write(wxT("/Assistant/PreviewWindow"), MY_G_CHOICE_VAL("prefs_ass_preview"));
+    cfg->Write(wxT("/Celeste/Auto"), MY_G_BOOL_VAL("prefs_celeste_auto"));
+    cfg->Write(wxT("/Assistant/AutoCPClean"), MY_G_BOOL_VAL("prefs_auto_cpclean"));
     // editor
     cfg->Write(wxT("/Stitcher/RunEditor"), MY_G_BOOL_VAL("prefs_ass_run_editor"));
     cfg->Write(wxT("/Stitcher/Editor"), MY_G_STR_VAL("prefs_ass_editor"));
@@ -718,7 +717,7 @@ void PreferencesDialog::UpdateConfigData()
     /////
     /// MISC
     // cache
-    cfg->Write(wxT("/ImageCache/UpperBound"), MY_G_SPIN_VAL("prefs_cache_UpperBound") << 20);
+    cfg->Write(wxT("/ImageCache/UpperBound"), (long) MY_G_SPIN_VAL("prefs_cache_UpperBound") << 20);
     // number of threads
     cfg->Write(wxT("/Nona/NumberOfThreads"), MY_G_SPIN_VAL("prefs_nona_NumberOfThreads"));
     
@@ -762,7 +761,6 @@ void PreferencesDialog::UpdateConfigData()
     cfg->Write(wxT("/Enfuse/Args"), MY_G_STR_VAL("prefs_enblend_EnfuseArgs"));
 
     // Celeste
-    cfg->Write(wxT("/Celeste/Auto"), MY_G_BOOL_VAL("prefs_celeste_auto"));
     t = MY_G_STR_VAL("prefs_celeste_threshold");
     td = HUGIN_CELESTE_THRESHOLD;
     utils::stringToDouble(std::string(t.mb_str(wxConvLocal)), td);
@@ -814,8 +812,8 @@ void PreferencesDialog::OnCPDetectorDelete(wxCommandEvent & e)
     }
     else
     {
-        if(wxMessageBox(wxString::Format(_("Do you really want to remove autopano setting \"%s\"?"),cpdetector_config_edit.settings[selection].GetCPDetectorDesc().c_str())
-            ,_("Delete autopano setting"),wxYES_NO | wxICON_QUESTION,this)==wxYES)
+        if(wxMessageBox(wxString::Format(_("Do you really want to remove control point detector setting \"%s\"?"),cpdetector_config_edit.settings[selection].GetCPDetectorDesc().c_str())
+            ,_("Delete control point detector setting"),wxYES_NO | wxICON_QUESTION,this)==wxYES)
         {
             if(cpdetector_config_edit.GetDefaultGenerator()==selection)
                 cpdetector_config_edit.SetDefaultGenerator(0);
