@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: PreviewFrame.cpp 4358 2009-09-10 05:06:53Z yuv $
+ *  $Id: PreviewFrame.cpp 4806 2009-12-14 20:37:26Z ade_br $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -65,7 +65,8 @@ enum {
     ID_TOGGLE_BUT = wxID_HIGHEST+100,
     PROJ_PARAM_NAMES_ID = wxID_HIGHEST+1000,
     PROJ_PARAM_VAL_ID = wxID_HIGHEST+1100,
-    PROJ_PARAM_SLIDER_ID = wxID_HIGHEST+1200
+    PROJ_PARAM_SLIDER_ID = wxID_HIGHEST+1200,
+    ID_FULL_SCREEN = wxID_HIGHEST+1700
 };
 
 BEGIN_EVENT_TABLE(PreviewFrame, wxFrame)
@@ -101,7 +102,7 @@ BEGIN_EVENT_TABLE(PreviewFrame, wxFrame)
     EVT_SCROLL_ENDSCROLL(PreviewFrame::OnChangeFOV)
     EVT_SCROLL_THUMBTRACK(PreviewFrame::OnChangeFOV)
 #endif
-
+    EVT_TOOL(ID_FULL_SCREEN, PreviewFrame::OnFullScreen)
 END_EVENT_TABLE()
 
 #define PF_STYLE (wxMAXIMIZE_BOX | wxRESIZE_BORDER | wxSYSTEM_MENU | wxCAPTION | wxCLOSE_BOX | wxCLIP_CHILDREN)
@@ -300,7 +301,7 @@ PreviewFrame::PreviewFrame(wxFrame * frame, PT::Panorama &pano)
                         0,        // not vertically strechable
                         wxALL | wxALIGN_CENTER_VERTICAL, // draw border all around
                         5);       // border width
-        m_projParamTextCtrl[i] = new wxTextCtrl(this, PROJ_PARAM_VAL_ID+i, _("0"),
+        m_projParamTextCtrl[i] = new wxTextCtrl(this, PROJ_PARAM_VAL_ID+i, wxT("0"),
                                     wxDefaultPosition,wxDefaultSize, wxTE_PROCESS_ENTER);
         m_projParamSizer->Add(m_projParamTextCtrl[i],
                         0,        // not vertically strechable
@@ -361,7 +362,14 @@ PreviewFrame::PreviewFrame(wxFrame * frame, PT::Panorama &pano)
         Show();
     }
     SetStatusText(_("Center panorama with left mouse button, set horizon with right button"),0);
-
+    wxAcceleratorEntry entries[1];
+    entries[0].Set(wxACCEL_NORMAL,WXK_F11,ID_FULL_SCREEN);
+    wxAcceleratorTable accel(1, entries);
+    SetAcceleratorTable(accel);
+#ifdef __WXGTK__
+    // set explicit focus to button panel, otherwise the hotkey F11 is not right processed
+    m_ButtonPanel->SetFocus();
+#endif
 }
 
 PreviewFrame::~PreviewFrame()
@@ -929,3 +937,13 @@ void PreviewFrame::updateProgressDisplay()
 #endif
 }
 
+void PreviewFrame::OnFullScreen(wxCommandEvent & e)
+{
+    ShowFullScreen(!IsFullScreen(), wxFULLSCREEN_NOBORDER | wxFULLSCREEN_NOCAPTION);
+#ifdef __WXGTK__
+    //workaround a wxGTK bug that also the toolbar is hidden, but not requested to hide
+    GetToolBar()->Show(true);
+#endif
+    m_PreviewPanel->ForceUpdate();
+};
+
