@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: PreviewPanel.cpp 4310 2009-09-01 12:34:44Z yuv $
+ *  $Id: PreviewPanel.cpp 4921 2010-01-20 06:21:35Z tmodes $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -143,6 +143,11 @@ void PreviewPanel::panoramaChanged(Panorama &pano)
         dirty = true;
     }
 
+    if (newOpts.getProjectionParameters() != opts.getProjectionParameters() ) {
+        DEBUG_DEBUG("projection parameters changed");
+        dirty = true;
+    }
+
     opts = newOpts;
     if (dirty) {
         // have to remap all images
