@@ -3,7 +3,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: config_defaults.h 4263 2009-08-23 02:47:14Z gpatters1 $
+ *  $Id: config_defaults.h 4949 2010-01-30 22:46:13Z brunopostle $
  *
  *  This is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -32,6 +32,8 @@
 #define HUGIN_ASS_PANO_DOWNSIZE_FACTOR        0.7
 #define HUGIN_ASS_AUTO_ALIGN                  0l
 #define HUGIN_ASS_OPT_PHOTOMETRIC             1l
+#define HUGIN_ASS_AUTO_CPCLEAN                1l
+#define HUGIN_ASS_PREVIEW                     1l
 
 // celeste panel
 #define HUGIN_CELESTE_AUTO                    0l
@@ -53,7 +55,7 @@
 
 
 // Image cache defaults
-#define HUGIN_IMGCACHE_UPPERBOUND             78643200
+#define HUGIN_IMGCACHE_UPPERBOUND             268435456
 #define HUGIN_IMGCACHE_MAPPING_INTEGER        0l
 #define HUGIN_IMGCACHE_MAPPING_FLOAT          1l
 #define HUGIN_CP_CURSOR                       1
@@ -170,4 +172,7 @@
 #define HUGIN_NONA_CROPPEDIMAGES                1l
 #define HUGIN_NONA_USEGPU                       0l
 
+// hdrmerge defaults
+#define HUGIN_HDRMERGE_ARGS                  "-m avg -c"
+
 #endif // _CONFIG_DEFAULTS_H
