@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: huginApp.cpp 4362 2009-09-10 16:16:26Z yuv $
+ *  $Id: huginApp.cpp 5025 2010-02-24 17:15:43Z brunopostle $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -57,6 +57,8 @@
 
 #include <tiffio.h>
 
+#include "AboutDialog.h"
+
 using namespace utils;
 
 // utility functions
@@ -229,15 +231,10 @@ bool huginApp::OnInit()
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("crop_panel.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("cp_list_frame.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("preview_frame.xrc"));
-    wxXmlResource::Get()->Load(m_xrcPrefix + wxT("run_optimizer_frame.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("edit_script_dialog.xrc"));
-    wxXmlResource::Get()->Load(m_xrcPrefix + wxT("run_stitcher_frame.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("main_menu.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("main_tool.xrc"));
-    wxXmlResource::Get()->Load(m_xrcPrefix + wxT("edit_text.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("about.xrc"));
-    wxXmlResource::Get()->Load(m_xrcPrefix + wxT("help.xrc"));
-    wxXmlResource::Get()->Load(m_xrcPrefix + wxT("keyboard_help.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("pref_dialog.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("cpdetector_dialog.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("reset_dialog.xrc"));
@@ -322,6 +319,8 @@ bool huginApp::OnInit()
 	opts.interpolator = (vigra_ext::Interpolator)config->Read(wxT("Nona/Interpolator"),HUGIN_NONA_INTERPOLATOR);
 	opts.remapUsingGPU = (bool)config->Read(wxT("Nona/useGPU"),HUGIN_NONA_USEGPU);
 	opts.tiff_saveROI = (bool)config->Read(wxT("Nona/CroppedImages"),HUGIN_NONA_CROPPEDIMAGES);
+    opts.hdrMergeMode = PanoramaOptions::HDRMERGE_AVERAGE;
+    opts.hdrmergeOptions = HUGIN_HDRMERGE_ARGS;
     pano.setOptions(opts);
 
     if (argc > 1) {
@@ -336,10 +335,14 @@ bool huginApp::OnInit()
                 filename.Prepend(wxFileName::GetPathSeparator());
                 filename.Prepend(cwd);
             }
+	    // Loading the project file with set actualPath to its
+	    // parent directory.  (actualPath is used as starting
+	    // directory by many subsequent file selection dialogs.)
             frame->LoadProjectFile(filename);
         } else {
             std::vector<std::string> filesv;
             for (int i=1; i< argc; i++) {
+		bool actualPathSet = false;
                 wxFileName file(argv[i]);
                 if (file.GetExt().CmpNoCase(wxT("jpg")) == 0 ||
                     file.GetExt().CmpNoCase(wxT("jpeg")) == 0 ||
@@ -353,7 +356,21 @@ bool huginApp::OnInit()
                     file.GetExt().CmpNoCase(wxT("hdr")) == 0 ||
                     file.GetExt().CmpNoCase(wxT("viff")) == 0 )
                 {
-                    filesv.push_back((const char *)(file.GetFullPath().mb_str(HUGIN_CONV_FILENAME)));
+		    wxString filename(argv[i]);
+		    // Make sure the filename is absolute.
+		    if (! wxIsAbsolutePath(filename)) {
+			filename.Prepend(wxFileName::GetPathSeparator());
+			filename.Prepend(cwd);
+		    }
+
+                    filesv.push_back((const char *)(filename.mb_str(HUGIN_CONV_FILENAME)));
+
+		    // Use the first filename to set actualPath.
+		    if (! actualPathSet) {
+			file = filename;
+			config->Write(wxT("/actualPath"), file.GetPath());
+			actualPathSet = true;
+		    }
                 }
             }
             GlobalCmdHist::getInstance().addCommand(
@@ -434,13 +451,17 @@ void RestoreFramePosition(wxTopLevelWindow * frame, const wxString & basename)
 
     wxConfigBase * config = wxConfigBase::Get();
 
+    // get display size
+    int dx,dy;
+    wxDisplaySize(&dx,&dy);
+
 #if ( __WXGTK__ ) &&  wxCHECK_VERSION(2,6,0)
 // restoring the splitter positions properly when maximising doesn't work.
 // Disabling maximise on wxWidgets >= 2.6.0 and gtk
         //size
         int w = config->Read(wxT("/") + basename + wxT("/width"),-1l);
         int h = config->Read(wxT("/") + basename + wxT("/height"),-1l);
-        if (w >0) {
+        if (w > 0 && w <= dx) {
             frame->SetClientSize(w,h);
         } else {
             frame->Fit();
@@ -448,7 +469,7 @@ void RestoreFramePosition(wxTopLevelWindow * frame, const wxString & basename)
         //position
         int x = config->Read(wxT("/") + basename + wxT("/positionX"),-1l);
         int y = config->Read(wxT("/") + basename + wxT("/positionY"),-1l);
-        if ( y >= 0 && x >= 0 && x < 4000 && y < 4000) {
+        if ( y >= 0 && x >= 0 && x < dx && y < dy) {
             frame->Move(x, y);
         } else {
             frame->Move(0, 44);
@@ -461,7 +482,7 @@ void RestoreFramePosition(wxTopLevelWindow * frame, const wxString & basename)
         //size
         int w = config->Read(wxT("/") + basename + wxT("/width"),-1l);
         int h = config->Read(wxT("/") + basename + wxT("/height"),-1l);
-        if (w >0) {
+        if (w > 0 && w <= dx) {
             frame->SetClientSize(w,h);
         } else {
             frame->Fit();
@@ -469,7 +490,7 @@ void RestoreFramePosition(wxTopLevelWindow * frame, const wxString & basename)
         //position
         int x = config->Read(wxT("/") + basename + wxT("/positionX"),-1l);
         int y = config->Read(wxT("/") + basename + wxT("/positionY"),-1l);
-        if ( y >= 0 && x >= 0) {
+        if ( y >= 0 && x >= 0 && x < dx && y < dy) {
             frame->Move(x, y);
         } else {
             frame->Move(0, 44);
