@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: wxPanoCommand.cpp 4439 2009-09-17 16:55:13Z yuv $
+ *  $Id: wxPanoCommand.cpp 5035 2010-02-28 21:46:20Z brunopostle $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -191,6 +191,20 @@ void wxAddImagesCmd::execute()
             wxMessageBox(wxString::Format(_("Could not decode image:\n%s\nAbort"), fname.c_str()), _("Unsupported image file format"));
             return;
         }
+        try
+        {
+            vigra::ImageImportInfo info(filename.c_str());
+            std::string pixelType=info.getPixelType();
+            if((pixelType=="UINT8") || (pixelType=="UINT16") || (pixelType=="INT16"))
+                srcImg.setResponseType(HuginBase::SrcPanoImage::RESPONSE_EMOR);
+            else
+                srcImg.setResponseType(HuginBase::SrcPanoImage::RESPONSE_LINEAR);
+        }
+        catch(std::exception & e) 
+        {
+            std::cerr << "ERROR: caught exception: " << e.what() << std::endl;
+            std::cerr << "Could not get pixel type for file " << filename << std::endl;
+        };
 //#if 0
         if (! ok && assumeSimilar) {
                  // search for image with matching size and exif data
@@ -425,8 +439,10 @@ void wxLoadPTProjectCmd::execute()
         PT::ControlPoint point = *it;
         SrcPanoImage img1 = pano.getSrcImage(point.image1Nr);
         SrcPanoImage img2 = pano.getSrcImage(point.image2Nr);
-        if (point.x1 > img1.getSize().x || point.y1 > img1.getSize().y ||
-           point.x2 > img2.getSize().x || point.y2 > img2.getSize().y) 
+        if (0 > point.x1 || point.x1 > img1.getSize().x || 
+            0 > point.y1 || point.y1 > img1.getSize().y ||
+            0 > point.x2 || point.x2 > img2.getSize().x || 
+            0 > point.y2 || point.y2 > img2.getSize().y) 
         {
             bad_cp_count++;
         } else 
