@@ -150,7 +150,7 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
                                             const std::string& tmpDir)
 {
     PanoramaOptions opts = pano.getOptions();
-#ifdef __unix__
+#ifdef UNIX_LIKE
     // set numeric locale to C, for correct number output
     char * t = setlocale(LC_NUMERIC,NULL);
     char * old_locale = (char*) malloc(strlen(t)+1);
@@ -158,7 +158,7 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
     setlocale(LC_NUMERIC,"C");
 #endif
 
-#ifdef __unix__
+#ifdef UNIX_LIKE
  std::string NULL_DEVICE("/dev/null");
 #else // WINDOWS
  std::string NULL_DEVICE("NUL");
@@ -187,7 +187,7 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
     // pass settings for different temporary directory
     if (tmpDir != "") {
         o << "# set temporary directory" << endl;
-#ifdef __unix__
+#ifdef UNIX_LIKE
         o << "export TMPDIR=" << quoteStringShell(tmpDir) << endl;
 #else // WINDOWS
         o << "export TEMP=" << quoteStringShell(tmpDir) << endl
@@ -274,7 +274,7 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
                 o << endl;
 
                 o << "ENBLEND_HDR_COMP=";
-                if (opts.outputImageType == "tif" && opts.outputImageTypeHDRCompression.size() != 0) {
+                if (opts.outputImageTypeHDR == "tif" && opts.outputImageTypeHDRCompression.size() != 0) {
                     o << "--compression " << opts.outputImageTypeHDRCompression;
                 }
                 o << endl;
@@ -312,6 +312,15 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
             break;
     }
 
+    switch (opts.hdrMergeMode)
+    {
+        case PanoramaOptions::HDRMERGE_AVERAGE:
+            o << "HDRMERGE_OPTS=" << opts.hdrmergeOptions << endl;
+            break;
+        case PanoramaOptions::HDRMERGE_DEGHOST:
+            break;
+    }
+
     o << "ENFUSE_OPTS=" << opts.enfuseOptions;
     // TODO: blend only over border if this is indeed a
     // image with 360 deg overlap
@@ -545,7 +554,6 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
         o << endl << endl;
         o << expImgVar.str() << "_INPUT_SHELL = ";
         for (UIntSet::iterator it = similarExposures[i].begin(); it != similarExposures[i].end();) {
-            exposure += pano.getSrcImage(*it).getExposureValue();
             std::ostringstream fns;
             fns << output << "_exposure_layers_" << std::setfill('0') << std::setw(4) << *it << ldrRemappedExt;
             o << quoteStringShell(fns.str());
@@ -864,7 +872,7 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
         // only output pixes that are defined in all input images
         for (unsigned i=0; i < stacks.size(); i++) {
             o << "$(HDR_STACK_" << i << ") : $(HDR_STACK_" << i << "_INPUT)" << endl
-            << "\t$(HDRMERGE) -m avg -c -o $(HDR_STACK_" << i << "_SHELL) $(HDR_STACK_" << i << "_INPUT_SHELL)" << endl
+            << "\t$(HDRMERGE) $(HDRMERGE_OPTS) -o $(HDR_STACK_" << i << "_SHELL) $(HDR_STACK_" << i << "_INPUT_SHELL)" << endl
             << endl;
         }
 
@@ -942,7 +950,7 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
 
                 // rules for non-blended HDR panoramas
                 o << "$(HDR_BLENDED) : $(HDR_LAYERS)" << endl;
-                o << "\t$(HDRMERGE) -m avg -o $(HDR_BLENDED_SHELL) $(HDR_LAYERS_SHELL)"   << endl << endl;
+                o << "\t$(HDRMERGE) $(HDRMERGE_OPTS) -o $(HDR_BLENDED_SHELL) $(HDR_LAYERS_SHELL)"   << endl << endl;
 
                 break;
             case PanoramaOptions::PTBLENDER_BLEND:
@@ -957,7 +965,7 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
         }
     }
 
-#ifdef __unix__
+#ifdef UNIX_LIKE
     // reset locale
     setlocale(LC_NUMERIC,old_locale);
     free(old_locale);
