@@ -8,7 +8,7 @@
  *
  * !! from PanoImage.h 1970
  *
- *  $Id: SrcPanoImage.cpp 4113 2009-07-27 05:30:19Z tmodes $
+ *  $Id: SrcPanoImage.cpp 4484 2009-09-25 01:53:37Z gpatters1 $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -604,7 +604,7 @@ bool SrcPanoImage::readEXIF(double & focalLength, double & cropFactor, double &
     getExiv2Value(exifData,"Exif.Photo.SubjectDistance", subjectDistance);
 
     std::string captureDate;
-    getExiv2Value(exifData,"Exif.Image.DateTime",captureDate);
+    getExiv2Value(exifData,"Exif.Photo.DateTimeOriginal",captureDate);
 
 
     // store some important EXIF tags for later usage.
